@@ -5,8 +5,9 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2015-2016 Statnet Commons
+#  Copyright 2015-2018 Statnet Commons
 #######################################################################
+#' @importFrom statnet.common statnetStartupMessage ERRVL NVL NVL3 all_identical despace eval_lhs.formula filter_rhs.formula list_rhs.formula nonsimp_update.formula paste.and set.control.class
 .onAttach <- function(lib, pkg){
   sm <- statnetStartupMessage("ergm.ego", c("statnet"), TRUE)
   if(!is.null(sm)){
@@ -14,3 +15,8 @@
   }
   
 }
+
+.onLoad <- function(lib, pkg){
+  # . is used in purrr and elsewhere.
+  utils::globalVariables(".")
+}
